# middleware-utils [![NPM version](https://img.shields.io/npm/v/middleware-utils.svg?style=flat)](https://www.npmjs.com/package/middleware-utils) [![NPM downloads](https://img.shields.io/npm/dm/middleware-utils.svg?style=flat)](https://npmjs.org/package/middleware-utils) [![Build Status](https://img.shields.io/travis/jonschlinkert/middleware-utils.svg?style=flat)](https://travis-ci.org/jonschlinkert/middleware-utils)

Utils for Template middleware.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save middleware-utils
```

## Usage

```js
var utils = require('middleware-utils');
```

## API

### [.series](index.js#L36)

Run one or more middleware in series.

**Params**

* `fns` **{Array|Function}**: Function or array of middleware functions

**Example**

```js
var utils = require('middleware-utils');
app.preRender(/\.hbs$/, utils.series([
  fn('foo'),
  fn('bar'),
  fn('baz')
]));

function fn(name) {
  return function(file, next) {
    console.log(name);
    next();
  };
}
```

### [.parallel](index.js#L79)

Run one or more middleware in parallel.

**Params**

* `fns` **{Array|Function}**: Function or array of middleware functions

**Example**

```js
var utils = require('middleware-utils');
app.preRender(/\.hbs$/, utils.parallel([
  fn('foo'),
  fn('bar'),
  fn('baz')
]));

function fn(name) {
  return function(file, next) {
    console.log(name);
    next();
  };
}
```

### [.error](index.js#L113)

Format errors for the middleware `done` function. Takes the name of the middleware method being handled.

**Params**

* `method` **{String}**: The middleware method name

**Example**

```js
app.postRender(/./, function(view, next) {
  // do stuff to view
  next();
}, utils.error('postRender'));
```

### [.handleError](index.js#L142)

Format errors for the `app.handle()` method.

**Params**

* `view` **{Object}**: View object
* `method` **{String}**: The middleware method name
* `next` **{String}**: Callback function

**Example**

```js
app.handle('onFoo', view, utils.handleError(view, 'onFoo'));
```

### [.delims](index.js#L170)

Returns a function for escaping and unescaping erb-style template delimiters.

**Params**

* `options` **{Object}**

**Example**

```js
var delims = mu.delims();
app.preRender(/\.tmpl$/, delims.escape());
app.postRender(/\.tmpl$/, delims.unescape());
```

## About

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Building docs

_(This document was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme) (a [verb](https://github.com/verbose/verb) generator), please don't edit the readme directly. Any changes to the readme must be made in [.verb.md](.verb.md).)_

To generate the readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install -g verb verb-generate-readme && verb
```

### Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

### Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

### License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/jonschlinkert/middleware-utils/blob/master/LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.1.28, on August 02, 2016._